# -*- coding: utf-8 -*-

"""
apimaticcalculator

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class OperationTypeEnum(object):

    """Implementation of the 'Operation Type' enum.

    Possible operators are sum, subtract, multiply, divide

    Attributes:
        SUM: Represents the sum operator
        SUBTRACT: Represents the subtract operator
        MULTIPLY: Represents the multiply operator
        DIVIDE: Represents the divide operator

    """
    SUM = 'SUM'

    SUBTRACT = 'SUBTRACT'

    MULTIPLY = 'MULTIPLY'

    DIVIDE = 'DIVIDE'

